Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(767)

Unified Diff: chrome/browser/chromeos/login/user_image_loader.h

Issue 236013002: Apply default wallpaper from customization manifest. (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: After-review. Created 6 years, 8 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: chrome/browser/chromeos/login/user_image_loader.h
diff --git a/chrome/browser/chromeos/login/user_image_loader.h b/chrome/browser/chromeos/login/user_image_loader.h
index 2b16726abab4c0729272f942369ffd846b48eada..97d6b1288fd3a685fc63b7ba254ff5949bc2dee2 100644
--- a/chrome/browser/chromeos/login/user_image_loader.h
+++ b/chrome/browser/chromeos/login/user_image_loader.h
@@ -53,9 +53,12 @@ class UserImageLoader : public base::RefCountedThreadSafe<UserImageLoader>,
// Contains attributes we need to know about each image we decode.
struct ImageInfo {
- ImageInfo(int size, const LoadedCallback& loaded_cb);
+ ImageInfo(const std::string& file_path,
+ int size,
+ const LoadedCallback& loaded_cb);
~ImageInfo();
+ const std::string file_path;
const int size;
Daniel Erat 2014/04/14 15:26:15 s/int/size_t/ (num_bytes might be a better name)
Alexander Alekseev 2014/04/15 01:57:16 |size| is image size in pixels and may be negative
const LoadedCallback loaded_cb;
};
@@ -64,10 +67,9 @@ class UserImageLoader : public base::RefCountedThreadSafe<UserImageLoader>,
virtual ~UserImageLoader();
- // Reads the image from |filepath| and starts the decoding process. This
- // method may only be invoked via the |background_task_runner_|.
- void ReadAndDecodeImage(const std::string& filepath,
- const ImageInfo& image_info);
+ // Reads the image from |image_info.file_path| and starts the decoding
+ // process. This method may only be invoked via the |background_task_runner_|.
+ void ReadAndDecodeImage(const ImageInfo& image_info);
// Decodes the image |data|. This method may only be invoked via the
// |background_task_runner_|.

Powered by Google App Engine
This is Rietveld 408576698